Learn R Programming

nmaINLA (version 1.1.0)

Anestheticdat: Data for the Anesthetic example in Greco et al. (2013)

Description

Greco et al. (2013) considered four anaesthetic agents used in cardiac surgery (called here 1, 2, 3 and 4) and investigated through NMA.

Usage

Anestheticdat

Arguments

Format

An object of class data.frame with 30 rows and 10 columns.