Learn R Programming

nmaINLA (version 1.1.0)

Dietaryfatdat: Data for the Dietary fat example in Dias et al. (2011)

Description

In a Cochrane Review of randomised controlled trials to assess the effect of change in dietary fats on total and cardiovascular mortality, 104 data extracted was in the form of rates and given as the number of events per person-years observed.

Usage

Dietaryfatdat

Arguments

Format

An object of class data.frame with 10 rows and 10 columns.