Learn R Programming

nmaINLA (version 1.1.0)

Parkinsondat: Data for the Parkinson NMA-network discussed in Dias et al. (2013)

Description

Data are the mean off-time reduction in patients given dopamine Agonists as adjunct therapy in Parkinson's disease. The data available are the mean, standard deviation and number of patients in each trial arm, for 7 studies of five different drugs: placebo, coded 1, and five active drugs coded 2 to 5.

Usage

Parkinsondat

Arguments

Format

An object of class data.frame with 7 rows and 11 columns.